import React from 'react';
import { Row, Col } from 'antd';
import {
  ProFormText,
  ProFormSelect,
  ProFormList,
} from '@ant-design/pro-components';
import { postTdQuestion, getTdQuestion, deleteTdQuestion, putTdQuestion } from '@/service/tdquestion';
import Curd from '@/components/Page/Curd';

export default React.forwardRef((props, ref) => {
  const actionRef = React.useRef();

  const columns = [
    {
      title: "问题类型",
      dataIndex: "quType",
      valueEnum: {
        1: {
          text: "单选",
          status: "radio",
        },
        0: {
          text: "填空题",
          status: "fill",
        },
      },
    },
    {
      title: "问题描述",
      dataIndex: "title",
    },
    {
      title: "正确答案",
      dataIndex: "rightAnswers",
    },
    {
      title: "状态",
      dataIndex: "status",
      valueEnum: {
        1: {
          text: "正常",
          status: "Processing",
        },
        0: {
          text: "禁用",
          status: "Error",
        },
      },
    },
  ]

  const Add = (data) => {
    postTdQuestion(data).then((res) => {
      actionRef.current.reload();
    })
  }

  const Edit = (row, data) => {
    console.log('fff', data);
    putTdQuestion(row, data).then((res) => {
      actionRef.current.reload();
    })
  }

  const Delete = (row) => {
    deleteTdQuestion(row).then(() => {
      actionRef.current.reload();
    })
  }

  return (
    <div>
      <Curd
        rowKey="quId"
        columns={columns}
        search={false}
        request={{
          list: getTdQuestion,
          save: Add,
          update: Edit,
          del: Delete,
        }}
        renderFormItems={() => (
          <>
            <ProFormText
              name="title"
              label="问题描述"
              placeholder="请填写"
              rules={[
                {
                  required: true,
                  message: '请填写题干',
                },
              ]}
            />
            <ProFormSelect
              name="quType"
              label="问题类型"
              fieldProps={{
                style: { width: '100%' }
              }}
              valueEnum={{
                radio: '单选',
                fill: '填空'
              }}
              rules={[
                {
                  required: true,
                  message: '请选择问题类型',
                },
              ]}
            />
            <ProFormList
              label="选项列表"
              copyIconProps={false}
              name="quAnswerList"
            >
              <Row gutter={24} style={{ width: '730px' }}>
                <Col span={6}>
                  <ProFormText
                    name="answerCode"
                    label="答案选项"
                    help="类似 A, B, C, D"
                  />
                </Col>
                <Col span={6}>
                  <ProFormText
                    name="answer"
                    label="答案"
                    placeholder="具体选项内容"
                  />
                </Col>
              </Row>
            </ProFormList>
          </>
        )}
      />
    </div>
  )
});
